Rename macros and types to namespace their usage

Macros and types have been renamed accordingly to namespace them by
their usage in the new kernel driver source tree structure.

This is done in a separate commit from the restructuring to avoid Git
from seeing some of the moved files as new ones because they have been
both moved and modified at the same time and thus losing the connection
in the history.

Change-Id: Icd4d8e8c76779479b5b46a55bf1d4f78a629c281
Signed-off-by: Mikael Olsson <mikael.olsson@arm.com>
diff --git a/kernel/include/rpmsg/ethosu_rpmsg_version.h b/kernel/include/rpmsg/ethosu_rpmsg_version.h
index 755a3d5..aa80835 100644
--- a/kernel/include/rpmsg/ethosu_rpmsg_version.h
+++ b/kernel/include/rpmsg/ethosu_rpmsg_version.h
@@ -17,8 +17,8 @@
  * http://www.gnu.org/licenses/gpl-2.0.html.
  */
 
-#ifndef ETHOSU_VERSION_H
-#define ETHOSU_VERSION_H
+#ifndef ETHOSU_RPMSG_VERSION_H
+#define ETHOSU_RPMSG_VERSION_H
 
 /****************************************************************************
  * Includes
@@ -33,27 +33,27 @@
  * Types
  ****************************************************************************/
 
-struct ethosu_core_msg_version_rsp;
+struct ethosu_rpmsg_version_rsp;
 
 /**
  * struct ethosu_version - Protocol version internal struct
  */
-struct ethosu_version {
-	struct device             *dev;
-	struct completion         done;
-	struct ethosu_mailbox_msg msg;
-	int                       errno;
+struct ethosu_rpmsg_version {
+	struct device                   *dev;
+	struct completion               done;
+	struct ethosu_rpmsg_mailbox_msg msg;
+	int                             errno;
 };
 
 /****************************************************************************
  * Functions
  ****************************************************************************/
 
-void ethosu_version_rsp(struct ethosu_mailbox *mailbox,
-			int msg_id,
-			struct ethosu_core_msg_version_rsp *rsp);
+void ethosu_rpmsg_version_rsp(struct ethosu_rpmsg_mailbox *mailbox,
+			      int msg_id,
+			      struct ethosu_rpmsg_version_rsp *rsp);
 
-int ethosu_version_check_request(struct device *dev,
-				 struct ethosu_mailbox *mailbox);
+int ethosu_rpmsg_version_check_request(struct device *dev,
+				       struct ethosu_rpmsg_mailbox *mailbox);
 
-#endif /* ETHOSU_VERSION_H */
+#endif /* ETHOSU_RPMSG_VERSION_H */
@@ -33,27 +33,27 @@
 
 /**
- * struct ethosu_version - Protocol version internal struct
+ * struct ethosu_rpmsg_version - Protocol version internal struct
  */